intelmq.bots.experts.truncate_by_delimiter package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.truncate_by_delimiter package

## Submodules

## intelmq.bots.experts.truncate_by_delimiter.expert module

Cut string if length is bigger than max

SPDX-FileCopyrightText: 2021 Marius Karotkis <marius.karotkis@gmail.com> SPDX-License-Identifier: AGPL-3.0-or-later

intelmq.bots.experts.truncate_by_delimiter.expert.BOT

  alias of `intelmq.bots.experts.truncate_by_delimiter.expert.TruncateByDelimiterExpertBot`

class intelmq.bots.experts.truncate_by_delimiter.expert.TruncateByDelimiterExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  delimiter: str = '.'
  field: str = 'source.fqdn'
  max_length: int = 200
  process()

## Module contents